@@ -1,6 +1,7 @@
 import json
 from typing import Any, Optional
 
+from argo_workflows.model.object_field_selector import ObjectFieldSelector
 from argo_workflows.models import (
     ConfigMapKeySelector,
     EnvVar,
@@ -98,3 +99,28 @@ class ConfigMapEnvSpec(EnvSpec):
                 config_map_key_ref=ConfigMapKeySelector(name=self.config_map_name, key=self.config_map_key)
             ),
         )
+
+
+class FieldEnvSpec(EnvSpec):
+    """Environment variable specification from K8S object field.
+
+    Attributes
+    ----------
+    field_path: str
+        The path of the object field to load values from.
+    api_version: Optional[str] = 'v1'
+        The version of the schema the FieldPath is written in terms of. Defaults to 'v1'.
+    """
+
+    field_path: str
+    api_version: Optional[str] = 'v1'
+
+    @property
+    def argo_spec(self) -> EnvVar:
+        """Constructs and returns the Argo environment specification"""
+        return EnvVar(
+            name=self.name,
+            value_from=EnvVarSource(
+                field_ref=ObjectFieldSelector(field_path=self.field_path, api_version=self.api_version)
+            ),
+        )
